@@ -1,4 +1,4 @@
 """Module handling all the project configurations."""
 AUTH0_JWKS_URL = "https://login.peachpayments.com/.well-known/jwks.json"
-PEACH_AUTH_SERVICE_BASE_URL = "https://qa-dashboard.ppay.io/"
+PEACH_AUTH_SERVICE_BASE_URL = "https://dashboard.peachpayments.com/"
 GENERATE_ACCESS_TOKEN_PATH = "api/oauth/token"
